// ConstantSpeed.pde
// -*- mode: C++ -*-
//
// Shows how to run AccelStepper in the simplest,
// fixed speed mode with no accelerations
// Requires the Adafruit_Motorshield v2 library 
//   https://github.com/adafruit/Adafruit_Motor_Shield_V2_Library
// And AccelStepper with AFMotor support 
//   https://github.com/adafruit/AccelStepper

// This tutorial is for Adafruit Motorshield v2 only!
// Will not work with v1 shields

#include <Wire.h>
#include <AccelStepper.h>
#include <Adafruit_MotorShield.h>

// Create the motor shield object with the default I2C address
Adafruit_MotorShield AFMS = Adafruit_MotorShield(); 
// Or, create it with a different I2C address (say for stacking)
// Adafruit_MotorShield AFMS = Adafruit_MotorShield(0x61); 

// Connect a stepper motor with 200 steps per revolution (1.8 degree)
// to motor port #2 (M3 and M4)
Adafruit_StepperMotor *myStepper1 = AFMS.getStepper(200, 2);

// you can change these to DOUBLE or INTERLEAVE or MICROSTEP!
void forwardstep1() {  
  myStepper1->onestep(FORWARD, SINGLE);
}
void backwardstep1() {  
  myStepper1->onestep(BACKWARD, SINGLE);
}

AccelStepper Astepper1(forwardstep1, backwardstep1); // use functions to step
int stepsPerSec = 50;
long startms;
long currentms;
long lastms;
long startpos;
long currentpos;

void setup()
{  
   Serial.begin(9600);           // set up Serial library at 9600 bps
   Serial.println("Stepper constant speed test");
  
  AFMS.begin();  // create with the default frequency 1.6KHz
  //AFMS.begin(1000);  // OR with a different frequency, say 1KHz

  Astepper1.setSpeed(stepsPerSec);	

  startpos = Astepper1.currentPosition();
  startms = millis();
  lastms = millis();
}

void loop()
{  
   Astepper1.runSpeed();
   currentms = millis();
   if((currentms - startms)>=60000) // every 1 minute
   {
    currentpos=Astepper1.currentPosition();
    Serial.print("Speed cmd = ");
    Serial.print(stepsPerSec);
    Serial.print(" steps per sec. Steps per min = ");
    Serial.print(60*stepsPerSec);
    Serial.print(". Steps taken in 1 min = ");
    Serial.print(currentpos-startpos);
    Serial.println();
    startms=currentms;
    startpos=currentpos; 
    if(stepsPerSec < 400) stepsPerSec+=50; else stepsPerSec=50; // increment the speed command
    Astepper1.setSpeed(stepsPerSec);
   } // end 1 minute process

}
